/*
 * This file and its contents are supplied under the terms of the
 * Common Development and Distribution License ("CDDL"), version 1.0.
 * You may only use this file in accordance with the terms of version
 * 1.0 of the CDDL.
 *
 * A full copy of the text of the CDDL should have accompanied this
 * source.  A copy of the CDDL is also available via the Internet at
 * http://www.illumos.org/license/CDDL.
 */

/*
 * Copyright 2012 David Hoeppner.  All rights reserved.
 */

#ifndef	_NETINET_DCCP_H
#define	_NETINET_DCCP_H

#ifdef	__cplusplus
extern "C" {
#endif

/*
 * DCCP header
 */
struct dccphdr {
	uint16_t	dh_sport;
	uint16_t	dh_dport;
	uint8_t		dh_offset;
#ifdef _BIT_FIELDS_LTOH
	uint8_t		dh_cscov:4,
			dh_ccval:4;
#else
	uint8_t		dh_ccval:4,
			dh_cscov:4;
#endif
	uint16_t	dh_sum;
#ifdef _BIT_FIELDS_LTOH
	uint8_t		dh_x:1,
			dh_type:4,
			dh_reserved:3;
#else
	uint8_t		dh_reserved:3,
			dh_type:4,
			dh_x:1;
#endif
	uint8_t		dh_res_seq;
	uint16_t	dh_seq;
};

#define	DCCPOPT_PADDING			0
#define	DCCPOPT_MANDATORY		1
#define	DCCPOPT_SLOW_RECEIVER		2
#define	DCCPOPT_CHANGE_L		32
#define	DCCPOPT_CONFIRM_L		33
#define	DCCPOPT_CHANGE_R		34
#define	DCCPOPT_CONFIRM_R		35
#define	DCCPOPT_INIT_COOKIE		36
#define	DCCPOPT_NDP_COUNT		37
#define	DCCPOPT_ACK_VECTOR_1		38
#define	DCCPOPT_ACK_VECTOR_2		39
#define	DCCPOPT_DATA_DROPPED		40
#define	DCCPOPT_TIMESTAMP		41
#define	DCCPOPT_TIMESTAMP_ECHO		42
#define	DCCPOPT_ELAPSED_TIME		43
#define	DCCPOPT_DATA_CHECKSUM		44

/*
 * Options for use with getsockopt and setsockopt.
 */

#define	DCCP_KEEPALIVE			0x08
#define	DCCP_NOTIFY_THRESHOLD		0x10
#define	DCCP_ABORT_THRESHOLD		0x11
#define	DCCP_CONN_NOTIFY_THRESHOLD	0x12
#define	DCCP_CONN_ABORT_THRESHOLD	0x13

#define	DCCP_KEEPALIVE_THRESHOLD	0x16
#define	DCCP_KEEPALIVE_ABORT_THRESHOLD	0x17

#define	DCCP_KEEPIDLE			0x22
#define	DCCP_KEEPCNT			0x23
#define	DCCP_KEEPINTVL			0x24

#ifdef	__cplusplus
}
#endif

#endif	/* _NETINET_DCCP_H */
